# Conflict test 
library(tidyverse)
library("plyr")
# for creating plots
library(ggplot2)
library(ggh4x)
library('egg')
# for calculating effect size 
library(rcompanion)
library("pwr")
# GLM 
library(car)
library(emmeans)


# read data
df_sh <- read.csv('C:/Users/aeo/Desktop/monkey cup/ms/data/df_Conflict.csv')
df_sh$side_correct <- factor(df_sh$side_correct)
df_sh$FirstTouch <- factor(df_sh$FirstTouch)


# descriptive statistics and plot ####################
# percentage for choosing spatial/ordinal cue
cal_acc <- df_sh[c("participant",'used_cue')] %>%
  group_by(participant,used_cue)%>%tally()%>%
  dplyr::group_by(participant)%>% dplyr::mutate (percent=n/sum(n)*100,N=sum(n))%>%
  subset(used_cue!='Neither')

df_sh$cue_spatial <- ifelse(df_sh$used_cue=='spatial',1,0)
df_sh$cue_ordinal <- ifelse(df_sh$used_cue=='ordinal',1,0)

# percentage for choosing spatial/ordinal cue by side 
cal_acc2 <- df_sh[c("participant","side_correct",'used_cue')] %>%
  group_by(participant,side_correct,used_cue)%>%tally()%>%
  dplyr::group_by(participant,side_correct)%>% dplyr::mutate (percent=n/sum(n)*100,N=sum(n))%>%
  subset(used_cue!='Neither')



# percentage of choosing each location 
describe_count<- df_sh %>% 
  group_by(participant,side_correct,FirstTouch) %>%
  tally() 

require(utils)


all_condition_sup <- expand.grid(participant = c("Hooke","Sally"),
                                 FirstTouch = c("1L","2L","3L","3R","2R","1R"), 
                                 side_correct = c("left","right"),
                                 stringsAsFactors = FALSE)

describe_count <- merge(all_condition_sup,describe_count,
                        by = c("participant","side_correct","FirstTouch"),all.x= TRUE)
describe_count[is.na(describe_count)] <- 0
describe_count <- describe_count%>%
  dplyr::group_by(participant,side_correct)%>% dplyr::mutate (percent=n/sum(n)*100,N=sum(n))


df_6dot <- data.frame()
describe_count0_6 <- subset(describe_count,n != 0)
for (i in 1:nrow(describe_count0_6)){
  tmp <- data.frame(participant = describe_count0_6$participant[i],
                    side_correct = describe_count0_6$side_correct[i],
                    FirstTouch = unique(describe_count0_6$FirstTouch))
  tmp$result[tmp$FirstTouch==describe_count0_6$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=describe_count0_6$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = describe_count0_6$n[i]-1), ])
  df_6dot <- rbind(df_6dot,tmp)
}
errorbar_6dot <- ddply(df_6dot, c("participant","side_correct","FirstTouch"), summarise,  
                       Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                       n = sum(!is.na(result)), se = sd / sqrt (n))
errorbar_6dot$FirstTouch <- factor(errorbar_6dot$FirstTouch,
                                   levels = c("1L","2L","3L","3R","2R","1R"))

# Figure 4 
ggplot(errorbar_6dot, aes(x=FirstTouch, y=Mean, colour = participant)) + 
  geom_hline(yintercept=16.67, color='grey', size=0.8)+
  geom_point(aes(shape=participant), size=3)+
  geom_line(aes(group = participant)) + 
  facet_grid(.~side_correct)+
  geom_point(size = 2) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.2, position=position_dodge(0)) +
  labs(title = "", x = "Positions", y="First choice %",
       shape="",color="") + 
  theme(text = element_text(size=15)) + 
  # guides(shape=FALSE)+
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue6"))+ 
  theme(text = element_text(size=16, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 16),
        strip.text.x = element_text(size = 16),
        strip.text.y = element_text(size = 16),
        legend.text = element_text(size = 16))
# ggsave("con6.tiff", plot = last_plot(),
#        path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 7, height =3.5, device='tiff', dpi=300)



# chance level #####################
# whether the use of spatial/ordinal cues were above chance 
for(i in 1:nrow(cal_acc)){
  chance <- 1/6
  tmp <-binom.test(cal_acc$n[i], cal_acc$N[i], p = chance,
                   alternative = c("greater"),
                   conf.level = 0.95)
  cal_acc$p[i] <- tmp['p.value']
  # cal_acc$p.adjust[i] <- p.adjust(tmp['p.value'],method="bonferroni",n=6)
  cal_acc$con_int[i] <- tmp['conf.int']
  cal_acc$chance[i] <- chance*100
  cal_acc$cohen_h[i] <- ES.h(cal_acc$percent[i]/100,chance)
  cal_acc$power[i] <- pwr.p.test(h=cal_acc$cohen_h[i] ,
                                 n=cal_acc$N[i],
                                 sig.level=0.05,alternative="greater")
}
cal_acc$sig[cal_acc$p<0.05] <- '*'
cal_acc$sig[cal_acc$p<0.01] <- '**'
cal_acc$sig[cal_acc$p<0.001] <- '***'
cal_acc
# cal_acc1 <- apply(cal_acc,2,as.character)
# write.csv(cal_acc1,'C:/Users/aeo/Desktop/monkey cup/plots/percent_conflict1.csv')


# spatial versus ordinal, proportional test 
# Hooke
prop.test(x = c(15, 39), n = c(72,72))
# Sally
prop.test(x = c(16, 42), n = c(72,72))
ES.h(0.20833,0.54167)
ES.h(0.22222,0.58333)



# test if each location was selected above chance 
for(i in 1:nrow(cal_acc2)){
  chance <- 1/6
  tmp <-binom.test(cal_acc2$n[i], cal_acc2$N[i], p = chance,
                   alternative = c("greater"),
                   conf.level = 0.95)
  cal_acc2$p[i] <- tmp['p.value']
  # cal_acc2$p.adjust[i] <- p.adjust(tmp['p.value'],method="bonferroni",n=6)
  cal_acc2$con_int[i] <- tmp['conf.int']
  cal_acc2$chance[i] <- chance*100
  cal_acc2$cohen_h[i] <- ES.h(cal_acc2$percent[i]/100,chance)
  cal_acc2$power[i] <- pwr.p.test(h=cal_acc2$cohen_h[i] ,
                                  n=cal_acc2$N[i],
                                  sig.level=0.05,alternative="greater")
}
cal_acc2$sig[cal_acc2$p<0.05] <- '*'
cal_acc2$sig[cal_acc2$p<0.01] <- '**'
cal_acc2$sig[cal_acc2$p<0.001] <- '***'
cal_acc2
# cal_acc21 <- apply(cal_acc2,2,as.character)
# write.csv(cal_acc21,'C:/Users/aeo/Desktop/monkey cup/plots/percent_conflict2.csv')




# GLMs on the number of first choices as a function of position (1L, 2L, 3L, 3R, 2R, 1R) and 
# target side (left vs. right) with a Poisson distribution were conducted for each monkey.##########################
# hooke
gmhooke<- glm(n~FirstTouch*side_correct, describe_count%>%
                filter(participant=="Hooke"),
              family="poisson")
summary(gmhooke)
Anova(gmhooke,type="III", test.statistic=c("LR"))
# Anova(gmhooke,type="III", test.statistic=c("F"))
side_touch_hooke = emmeans(gmhooke, ~ side_correct *FirstTouch)
pairs(side_touch_hooke, simple = "side_correct",adjust="bonferroni")
pairs(side_touch_hooke, simple = "FirstTouch",adjust="bonferroni")

# Sally
gmsally<- glm(n~FirstTouch*side_correct, describe_count%>%filter(participant=="Sally"),
              family="poisson")

summary(gmsally)
Anova(gmsally,type="III", test.statistic=c("LR"))
# Anova(gmsally,type="III", test.statistic=c("F"))
side_touch_sally = emmeans(gmsally, ~ side_correct *FirstTouch)
pairs(side_touch_sally, simple = "side_correct",adjust="bonferroni")
pairs(side_touch_sally, simple = "FirstTouch",adjust="bonferroni")
#

