# Continuous transfer test
library(tidyverse)
library("plyr")
# for creating plots
library(ggplot2)
library(ggh4x)
library('egg')
# for calculating effect size 
library(rcompanion)
library("pwr")
# GLM 
library(car)
library(emmeans)

# read data
df_sh <- read.csv('C:/Users/aeo/Desktop/monkey cup/ms/data/df_ContinuousTransfer.csv')

creat_ord <- function(df){
  df$ord_position[df$correct_dot=='1R'] <- '1st'
  df$ord_position[df$correct_dot=='1L'] <- '1st'
  df$ord_position[df$correct_dot=='2R'] <- '2nd'
  df$ord_position[df$correct_dot=='2L'] <- '2nd'
  df$ord_position[df$correct_dot=='3R'] <- '3rd'
  df$ord_position[df$correct_dot=='3L'] <- '3rd'
  df$ord_position[df$correct_dot=='4R'] <- '4th'
  df$ord_position[df$correct_dot=='4L'] <- '4th'
  return(df)
}
creat_side <- function(df){
  df$side_correct[grepl('R',df$correct_dot, fixed = TRUE)] <- 'right'
  df$side_correct[grepl('L',df$correct_dot, fixed = TRUE)] <- 'left'
  return(df)
}

# plot dots vs. line  accuracy Figure 5###############
percent_10dots <- df_sh %>% 
  group_by(participant,expName,correct_dot,FirstTouch,ord_position,side_correct)%>%tally()%>%
  dplyr::group_by(participant,expName,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100)

all_condition <- expand.grid(participant = c("Hooke","Sally"), 
                             expName = c('line','dots'),
                             correct_dot = c("2L","3L","4L","4R","3R","2R"),
                             FirstTouch= c("1L","2L","3L","4L","5L","5R","4R","3R","2R","1R"),stringsAsFactors = FALSE)
all_condition <- creat_ord(all_condition)
all_condition <- creat_side(all_condition)


percent_10dots <- merge(all_condition,percent_10dots,by = 
                          c("participant",'expName',"correct_dot","FirstTouch","ord_position","side_correct"),all.x= TRUE)
percent_10dots$percent[is.na(percent_10dots$percent)] <-0
percent_10dots$correct_dot <- factor(percent_10dots$correct_dot,levels = 
                                       c("2L","3L","4L","4R","3R","2R"))
# c("2L","3L","4L","2R","3R","4R"))
percent_10dots$FirstTouch <- factor(percent_10dots$FirstTouch,levels = 
                                      c("1L","2L","3L","4L","5L","5R","4R","3R","2R","1R"))


df_10dot <- data.frame()
percent_10dots0 <- subset(percent_10dots,n != 0)
for (i in 1:nrow(percent_10dots0)){
  tmp <- data.frame(participant = percent_10dots0$participant[i],
                    correct_dot = percent_10dots0$correct_dot[i],
                    expName = percent_10dots0$expName[i],
                    FirstTouch = unique(percent_10dots0$FirstTouch))
  tmp$result[tmp$FirstTouch==percent_10dots0$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=percent_10dots0$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = percent_10dots0$n[i]-1), ])
  df_10dot <- rbind(df_10dot,tmp)
}


errorbar_10dot <- ddply(df_10dot, c("participant",'expName',"correct_dot","FirstTouch"), summarise,  
                        Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                        n = sum(!is.na(result)), se = sd / sqrt (n))
errorbar_10dot <- errorbar_10dot%>%filter(as.character(correct_dot)==as.character(FirstTouch))
errorbar_10dot$correct_dot <- factor(errorbar_10dot$correct_dot,levels = 
                                       c('2L','3L','4L','4R','3R','2R'))
errorbar_10dot$expName <- mapvalues(errorbar_10dot$expName,
                                    from = 
                                      c('dots','line'),
                                    to = c('number transfer','spatial transfer'))
# Figure 5 
ggplot(errorbar_10dot, aes(x=correct_dot, y=Mean, colour = expName,shape = expName)) +  
  # geom_line(aes(group = participant)) +
  facet_wrap(.~participant,ncol=2)+
  geom_point(size = 3) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.4, position=position_dodge(0)) +
  labs(title = "", x = "Target position", y="Accuracy (%)",shape='Experiment',color="Experiment") + 
  theme(legend.position="right")+  
  geom_hline(yintercept=10, color='grey', size=0.8) +
  # guides(shape=FALSE)+ 
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14)) 
# ggsave("line_dots_acc.tiff", plot = last_plot(),path = "C:/Users/aeo/Desktop",
#        width = 7, height =3, device='tiff', dpi=300)


# binomial test against chance ###################

# overall performance against chance
percent_correct_exp <- df_sh%>%  filter(expName=='line')%>%
  group_by(participant,correct)%>%tally()%>%
  dplyr::group_by(participant)%>%dplyr::mutate (percent=n/sum(n)*100,N = sum(n)) %>%
  subset(correct==1)

for(i in 1:nrow(percent_correct_exp)){
  # chance <- 1/(tidyr::extract_numeric(percent_correct_exp$expName[i]))
  tmp <-binom.test(percent_correct_exp$n[i], percent_correct_exp$N[i], p = 0.1,
                   alternative = c("greater"),
                   conf.level = 0.95)
  # percent_correct_exp$chance[i] <- chance*100
  percent_correct_exp$p[i] <- tmp['p.value']
  percent_correct_exp$cohen_h[i] <- ES.h(percent_correct_exp$percent[i]/100,0.1)
  percent_correct_exp$power[i] <- pwr.p.test(h=percent_correct_exp$cohen_h[i] ,
                                             n=percent_correct_exp$N[i],
                                             sig.level=0.05,alternative="greater")
  # percent_correct_exp$estimate[i] <- tidyr::extract_numeric(tmp['estimate'])
  percent_correct_exp$con_int[i] <- tmp['conf.int']
}
percent_correct_exp$sig[percent_correct_exp$p<0.05] <- '*'
percent_correct_exp$sig[percent_correct_exp$p<0.01] <- '**'
percent_correct_exp$sig[percent_correct_exp$p<0.001] <- '***'



# whether each target location was remembered 
percent_correct <- df_sh%>% filter(expName=='line')%>%
  group_by(participant,correct_dot,FirstTouch)%>%tally()%>%
  dplyr::group_by(participant,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100,N = sum(n)) %>%
  subset(correct_dot==FirstTouch)

for(i in 1:nrow(percent_correct)){
  # chance <- 1/(tidyr::extract_numeric(percent_correct$expName[i]))
  tmp <-binom.test(percent_correct$n[i], percent_correct$N[i], p = 0.1,
                   alternative = c("greater"),
                   conf.level = 0.95)
  # percent_correct$chance[i] <- chance*100
  percent_correct$cohen_h[i] <- ES.h(percent_correct$percent[i]/100,0.1)
  percent_correct$power[i] <- pwr.p.test(h=percent_correct$cohen_h[i] ,
                                         n=percent_correct$N[i],
                                         sig.level=0.05,alternative="greater")
  percent_correct$p[i] <- tmp['p.value']
  # percent_correct$p.adjust[i] <- p.adjust(tmp['p.value'],method="bonferroni",n=10)
  
  
  # percent_correct$con_int[i] <- tmp['conf.int']
}
percent_correct$sig[percent_correct$p<0.05] <- '*'
percent_correct$sig[percent_correct$p<0.01] <- '**'
percent_correct$sig[percent_correct$p<0.001] <- '***'
errorbar_10line <- errorbar_10dot%>%subset(expName=='spatial transfer')
percent_correct <- merge(percent_correct,errorbar_10line[c('participant','correct_dot','se')],
                         by=c('participant','correct_dot'))

percent_correct1 <- apply(percent_correct,2,as.character)
# write.csv(percent_correct1,'C:/Users/aeo/Desktop/monkey cup/ms/percent_correct3.csv')


# lateral response: whether they remembered left targets better than the right  
sally2 <- df_sh%>%subset(participant=="Sally")
hooke2 <- df_sh%>%subset(participant=="Hooke")
# left versus right 
wilcox.test(correct ~ side_correct, data= hooke2)
wilcoxonR(hooke2$correct, hooke2$side_correct)

wilcox.test(correct ~ side_correct, data= sally2)
wilcoxonR(sally2$correct, sally2$side_correct)


# binomial GLMs accuracy (1 or 0) as a function of target positions and experimental condition ----------------------------
# Hooke
gmhooke<- glm(correct ~ correct_dot*expName,
                data=hooke2, 
                family = "binomial"(link="logit"))

summary(gmhooke)
Anova(gmhooke,type="III")
exp_pos_hooke = emmeans(gmhooke, ~ correct_dot*expName)
pairs(exp_pos_hooke, simple = "expName",adjust="bonferroni",paired=TRUE)
pairs(exp_pos_hooke, simple = "correct_dot",adjust="bonferroni",paired=TRUE)

# Sally 
gmsally<- glm(correct ~ correct_dot*expName,
              data=sally2, 
              family = "binomial"(link="logit"))

summary(gmsally)
Anova(gmsally,type="III")
pos_sally = emmeans(gmsally, ~ correct_dot)
pairs(pos_sally, simple = "correct_dot",adjust="bonferroni",paired=TRUE)



