# Number transfer test
library(tidyverse)
library("plyr")
# for creating plots
library(ggplot2)
library(ggh4x)
library('egg')
# for calculating effect size 
library(rcompanion)
library("pwr")
# GLM 
library(car)
library(emmeans)





# read data
df_sh <- read.csv('C:/Users/aeo/Desktop/monkey cup/ms/data/df_NumberTransfer.csv')

creat_ord <- function(df){
  df$ord_position[df$correct_dot=='1R'] <- '1st'
  df$ord_position[df$correct_dot=='1L'] <- '1st'
  df$ord_position[df$correct_dot=='2R'] <- '2nd'
  df$ord_position[df$correct_dot=='2L'] <- '2nd'
  df$ord_position[df$correct_dot=='3R'] <- '3rd'
  df$ord_position[df$correct_dot=='3L'] <- '3rd'
  df$ord_position[df$correct_dot=='4R'] <- '4th'
  df$ord_position[df$correct_dot=='4L'] <- '4th'
  return(df)
}
creat_side <- function(df){
  df$side_correct[grepl('R',df$correct_dot, fixed = TRUE)] <- 'right'
  df$side_correct[grepl('L',df$correct_dot, fixed = TRUE)] <- 'left'
  return(df)
}

# descriptive statistics and plot  #######################################
# ddply(df_sh, c("participant","expName"), summarise,  Mean = mean(correct), sd = sd(correct), n = sum(!is.na(correct)), se = sd / sqrt (n))


# calculate the accuracy of each monkey in each experiment of the Number transfer test (Table 1)
describe_mean0 <- ddply(df_sh, c("participant","expName"), summarise,  
                        Mean = mean(correct)*100, sd = sd(correct)*100, sum = sum(correct),
                        n = sum(!is.na(correct)), se = sd / sqrt (n))

# calculate the accuracy of each monkey by experiment and the side of target
describe_mean <- ddply(df_sh, c("participant","expName","side_correct"), summarise,  
                       Mean = mean(correct)*100, sd = sd(correct)*100, sum = sum(correct),
                       n = sum(!is.na(correct)), se = sd / sqrt (n))
describe_mean$expName <-  factor(describe_mean$expName, levels = c("2-dot","4-dot","6-dot","10-dot"))
# windowsFonts(Times=windowsFont("Arial"))
# Figure 3 Monkeys’ accuracy in number transfer tests on each side. 
ggplot(describe_mean, aes(x=expName, y=Mean, colour = side_correct)) + 
  geom_point(aes(shape=side_correct), size=3)+
  geom_line(aes(group = side_correct)) + 
  facet_wrap(.~participant)+
  geom_point(size = 2) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.2, position=position_dodge(0)) +
  labs(title = "", x = "Experiment", y="Accuracy %",color='Target side',shape='Target side') + 
  theme(text = element_text(size=15)) + 
  # geom_hline(yintercept=10, color='grey', size=0.8)+
  # guides(shape=FALSE)+
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14))
# save plot 
# ggsave("acc_side_num.tiff", plot = last_plot(),
#        path = "C:/Users/aeo/Desktop",
#        width = 7, height =3, device='tiff', dpi=300)




# Figure 2  The percentage of choosing each position as a function of target position and subject in number transfer tests:2-, 4-, 6-, 10-dot array.  ------ 
# two-dot four-dot experiment 
# calculate the mean accuracy 
percent_2dots <- df_sh %>%subset(expName=="2-dot")%>%
  group_by(participant,correct_dot,FirstTouch)%>%tally()%>%
  dplyr::group_by(participant,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100)
# calculate the standard error 
df_2dot <- data.frame()
percent_2dots0 <- subset(percent_2dots,n != 0)
for (i in 1:nrow(percent_2dots0)){
  tmp <- data.frame(participant = percent_2dots0$participant[i],
                    correct_dot = percent_2dots0$correct_dot[i],
                    FirstTouch = unique(percent_2dots0$FirstTouch))
  tmp$result[tmp$FirstTouch==percent_2dots0$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=percent_2dots0$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = percent_2dots0$n[i]-1), ])
  df_2dot <- rbind(df_2dot,tmp)
}

errorbar_2dot <- ddply(df_2dot, c("participant","correct_dot","FirstTouch"), summarise,  
                       Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                       n = sum(!is.na(result)), se = sd / sqrt (n))
# Figure 2a
p_per_2 <- ggplot(errorbar_2dot, aes(x=FirstTouch, y=Mean, colour = participant,shape = participant)) +  
  geom_hline(yintercept=50, color='grey', size=0.8) +
  geom_line(aes(group = participant)) +
  facet_grid(.~correct_dot)+
  geom_point(size = 3) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.2, position=position_dodge(0)) +
  labs(title = "", x = "Position", y="First choice %",shape='',color="") + 
  theme(legend.position="right")+  
  # guides(shape=FALSE)+ 
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14)) 
p_per_2
# ggsave("percent_2.tiff", plot = last_plot(),path = "C:/Users/aeo/Desktop",
#        width = 7, height =3, device='tiff', dpi=300)




# four-dot experiment 
percent_4dots <- df_sh %>%subset(expName=="4-dot")%>% 
  group_by(participant,correct_dot,FirstTouch,ord_position,side_correct)%>%tally()%>%
  dplyr::group_by(participant,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100)
# to spread data and calculate standard error
all_condition <- expand.grid(participant = c("Hooke","Sally"), 
                             correct_dot = c("1L","2L","2R","1R"),
                             FirstTouch= c("1L","2L","2R","1R"),stringsAsFactors = FALSE)
all_condition <- creat_ord(all_condition)
all_condition <- creat_side(all_condition)
percent_4dots <- merge(all_condition,percent_4dots,by = 
                         c("participant","correct_dot","FirstTouch","ord_position","side_correct"),all.x= TRUE)
percent_4dots$percent[is.na(percent_4dots$percent)] <-0
percent_4dots$n[is.na(percent_4dots$n)] <-0
percent_4dots$correct_dot <- factor(percent_4dots$correct_dot,levels = 
                                      c("1L","2L","2R","1R"))
percent_4dots$FirstTouch <- factor(percent_4dots$FirstTouch,levels = 
                                     c("1L","2L","2R","1R"))
df_4dot <- data.frame()
percent_4dots0 <- subset(percent_4dots,n != 0)
for (i in 1:nrow(percent_4dots0)){
  tmp <- data.frame(participant = percent_4dots0$participant[i],
                    correct_dot = percent_4dots0$correct_dot[i],
                    FirstTouch = unique(percent_4dots0$FirstTouch))
  tmp$result[tmp$FirstTouch==percent_4dots0$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=percent_4dots0$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = percent_4dots0$n[i]-1), ])
  df_4dot <- rbind(df_4dot,tmp)
}

errorbar_4dot <- ddply(df_4dot, c("participant","correct_dot","FirstTouch"), summarise,  
                       Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                       n = sum(!is.na(result)), se = sd / sqrt (n))
# Figure 2b
p_per_4 <- ggplot(errorbar_4dot, aes(x=FirstTouch, y=Mean, colour = participant,shape = participant)) +  
  geom_hline(yintercept=25, color='grey', size=0.8) +
  geom_line(aes(group = participant)) +
  facet_grid(.~correct_dot)+
  geom_point(size = 3) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.2, position=position_dodge(0)) +
  labs(title = "", x = "Position", y="First choice %",shape='',color="") + 
  theme(legend.position="right")+  
  # guides(shape=FALSE)+ 
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14)) 
p_per_4
# ggsave("percent_4.tiff", plot = last_plot(),path = "C:/Users/aeo/Desktop",
#        width = 10, height =3, device='tiff', dpi=300)



# six-dot expeirment 
percent_6dots <- df_sh %>%subset(expName=="6-dot")%>% 
  group_by(participant,correct_dot,FirstTouch,ord_position,side_correct)%>%tally()%>%
  dplyr::group_by(participant,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100)
all_condition <- expand.grid(participant = c("Hooke","Sally"), 
                             correct_dot = c("2L","3L","3R","2R"),
                             FirstTouch= c("1L","2L","3L","3R","2R","1R"),stringsAsFactors = FALSE)
all_condition <- creat_ord(all_condition)
all_condition <- creat_side(all_condition)
percent_6dots <- merge(all_condition,percent_6dots,by = 
                         c("participant","correct_dot","FirstTouch","ord_position","side_correct"),all.x= TRUE)
percent_6dots$percent[is.na(percent_6dots$percent)] <-0
percent_6dots$correct_dot <- factor(percent_6dots$correct_dot,levels = 
                                      c("2L","3L","3R","2R"))
percent_6dots$FirstTouch <- factor(percent_6dots$FirstTouch,levels = 
                                     c("1L","2L","3L","3R","2R","1R"))

df_6dot <- data.frame()
percent_6dots0 <- subset(percent_6dots,n != 0)
for (i in 1:nrow(percent_6dots0)){
  tmp <- data.frame(participant = percent_6dots0$participant[i],
                    correct_dot = percent_6dots0$correct_dot[i],
                    FirstTouch = unique(percent_6dots0$FirstTouch))
  tmp$result[tmp$FirstTouch==percent_6dots0$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=percent_6dots0$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = percent_6dots0$n[i]-1), ])
  df_6dot <- rbind(df_6dot,tmp)
}

errorbar_6dot <- ddply(df_6dot, c("participant","correct_dot","FirstTouch"), summarise,  
                       Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                       n = sum(!is.na(result)), se = sd / sqrt (n))
# Figure 2c
p_per_6 <- ggplot(errorbar_6dot, aes(x=FirstTouch, y=Mean, colour = participant,shape = participant)) +  
  geom_hline(yintercept=16.67, color='grey', size=0.8) +
  geom_line(aes(group = participant)) +
  facet_grid(.~correct_dot)+
  geom_point(size = 3) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.2, position=position_dodge(0)) +
  labs(title = "", x = "Position", y="First choice %",shape='',color="") + 
  theme(legend.position="right")+  
  # guides(shape=FALSE)+ 
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14)) 
p_per_6
# ggsave("percent_6.tiff", plot = last_plot(),path = "C:/Users/aeo/Desktop",
#        width = 10, height =3, device='tiff', dpi=300)



# ten-dot experiment 
percent_10dots <- df_sh %>%subset(expName=="10-dot")%>% 
  group_by(participant,correct_dot,FirstTouch,ord_position,side_correct)%>%tally()%>%
  dplyr::group_by(participant,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100)
all_condition <- expand.grid(participant = c("Hooke","Sally"), 
                             correct_dot = c("2L","3L","4L","4R","3R","2R"),
                             FirstTouch= c("1L","2L","3L","4L","5L","5R","4R","3R","2R","1R"),stringsAsFactors = FALSE)
all_condition <- creat_ord(all_condition)
all_condition <- creat_side(all_condition)
percent_10dots <- merge(all_condition,percent_10dots,by = 
                          c("participant","correct_dot","FirstTouch","ord_position","side_correct"),all.x= TRUE)
percent_10dots$percent[is.na(percent_10dots$percent)] <-0
percent_10dots$correct_dot <- factor(percent_10dots$correct_dot,levels = 
                                       c("2L","3L","4L","4R","3R","2R"))
# c("L2","L3","L4","R2","R3","R4"))
percent_10dots$FirstTouch <- factor(percent_10dots$FirstTouch,levels = 
                                      c("1L","2L","3L","4L","5L","5R","4R","3R","2R","1R"))
df_10dot <- data.frame()
percent_10dots0 <- subset(percent_10dots,n != 0)
for (i in 1:nrow(percent_10dots0)){
  tmp <- data.frame(participant = percent_10dots0$participant[i],
                    correct_dot = percent_10dots0$correct_dot[i],
                    FirstTouch = unique(percent_10dots0$FirstTouch))
  tmp$result[tmp$FirstTouch==percent_10dots0$FirstTouch[i]]<-1
  tmp$result[tmp$FirstTouch!=percent_10dots0$FirstTouch[i]]<-0
  tmp <- tmp %>% rbind(tmp[rep(seq_len(nrow(tmp)), each = percent_10dots0$n[i]-1), ])
  df_10dot <- rbind(df_10dot,tmp)
}


errorbar_10dot <- ddply(df_10dot, c("participant","correct_dot","FirstTouch"), summarise,  
                        Mean = mean(result)*100, sd = sd(result)*100, sum = sum(result),
                        n = sum(!is.na(result)), se = sd / sqrt (n))

p_per_10 <- ggplot(errorbar_10dot, aes(x=FirstTouch, y=Mean, colour = participant,shape = participant)) +  
  geom_hline(yintercept=10, color='grey', size=0.8) +
  geom_line(aes(group = participant)) +
  facet_wrap(.~correct_dot,ncol=3)+
  geom_point(size = 3) +
  ylim(0,100) +
  geom_errorbar(aes(ymin=(Mean-se), ymax=(Mean+se)), width=0.4, position=position_dodge(0)) +
  labs(title = "", x = "Position", y="First choice %",shape='',color="") + 
  theme(legend.position="right")+  
  # guides(shape=FALSE)+ 
  theme_classic() + 
  # scale_color_manual(values=c("deepskyblue", "deepskyblue4"))+ 
  theme(text = element_text(size=14, family="Times"), 
        panel.background = element_rect(fill = "transparent", color = "black"), 
        plot.background = element_rect(fill = "transparent")) + 
  theme(axis.text.x = element_text(size = 10),
        axis.text.y = element_text(size = 14),
        strip.text.x = element_text(size = 14),
        strip.text.y = element_text(size = 14),
        legend.text = element_text(size = 14)) 
p_per_10
# ggsave("percent_10.tiff", plot = last_plot(),path = "C:/Users/aeo/Desktop",
#        width = 10, height =5, device='tiff', dpi=300)

# save figure 2 with the same size of each panel 


p_per_2 <- p_per_2 + force_panelsizes(rows =unit(1.5,"in"),cols =unit(1.8,"in"))
p_per_4 <- p_per_4 + force_panelsizes(rows =unit(1.5,"in"),cols =unit(1.8,"in"))
p_per_6 <- p_per_6 + force_panelsizes(rows =unit(1.5,"in"),cols =unit(1.8,"in"))
p_per_10 <- p_per_10 + force_panelsizes(rows =unit(1.5,"in"),cols =unit(1.8,"in"))
# ggsave("percent.tiff", plot = p_per_t, path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 10, height = 14, device='tiff', dpi=300)
# ggsave("percent_2.tiff", plot = p_per_2, path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 10, height = 2.5, device='tiff', dpi=300)
# ggsave("percent_4.tiff", plot = p_per_4, path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 10, height = 2.5, device='tiff', dpi=300)
# ggsave("percent_6.tiff", plot = p_per_6, path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 10, height = 2.5, device='tiff', dpi=300)
# ggsave("percent_10.tiff", plot = p_per_10, path = "C:/Users/aeo/Desktop/monkey cup/plots",
#        width = 10, height = 4.5, device='tiff', dpi=300)



# binomial test against chance ###################
# test if each monkey succeeded in each experiment-----
percent_correct_exp <- df_sh%>% 
  group_by(participant,expName,correct)%>%tally()%>%
  dplyr::group_by(participant,expName)%>%dplyr::mutate (percent=n/sum(n)*100,N = sum(n)) %>%
  subset(correct==1)
for(i in 1:nrow(percent_correct_exp)){
  chance <- 1/(as.numeric(strsplit(percent_correct_exp$expName[i], "-")[[1]][1]))
  # print(chance)
  tmp <-binom.test(percent_correct_exp$n[i], percent_correct_exp$N[i], p = chance,
                   alternative = c("greater"),
                   conf.level = 0.95)
  percent_correct_exp$chance[i] <- chance*100
  percent_correct_exp$p[i] <- tmp['p.value']
  percent_correct_exp$cohen_h[i] <- ES.h(percent_correct_exp$percent[i]/100,chance/100)
  percent_correct_exp$power[i] <- pwr.p.test(h=percent_correct_exp$cohen_h[i] ,
                                             n=percent_correct_exp$N[i],
                                             sig.level=0.05,alternative="greater")
  # percent_correct_exp$estimate[i] <- tidyr::extract_numeric(tmp['estimate'])
  percent_correct_exp$con_int[i] <- tmp['conf.int']
}
percent_correct_exp$sig[percent_correct_exp$p<0.05] <- '*'
percent_correct_exp$sig[percent_correct_exp$p<0.01] <- '**'
percent_correct_exp$sig[percent_correct_exp$p<0.001] <- '***'
percent_correct_exp
# percent_correct_exp1 <- apply(percent_correct_exp,2,as.character)
# write.csv(percent_correct_exp1,'C:/Users/aeo/Desktop/monkey cup/plots/percent_correct_exp.csv')
# percent_correct2 <- apply(percent_correct,2,as.character)
# write.csv(percent_correct2,'C:/Users/aeo/Desktop/monkey cup/plots/percent_correct_num.csv')



# test if each target location was selected above chance ----
percent_correct <- df_sh%>% 
  group_by(participant,expName,correct_dot,FirstTouch)%>%tally()%>%
  dplyr::group_by(participant,expName,correct_dot)%>%dplyr::mutate (percent=n/sum(n)*100,N = sum(n)) %>%
  subset(correct_dot==FirstTouch)

for(i in 1:nrow(percent_correct)){
  chance <- 1/(as.numeric(strsplit(percent_correct$expName[i], "-")[[1]][1]))
  tmp <-binom.test(percent_correct$n[i], percent_correct$N[i], p = chance,
                   alternative = c("greater"),
                   conf.level = 0.95)
  percent_correct$chance[i] <- chance*100
  percent_correct$cohen_h[i] <- ES.h(percent_correct$percent[i]/100,chance)
  percent_correct$power[i] <- pwr.p.test(h=percent_correct$cohen_h[i] ,
                                         n=percent_correct$N[i],
                                         sig.level=0.05,alternative="greater")
  percent_correct$p[i] <- tmp['p.value']
  # percent_correct$p.adjust[i] <- p.adjust(percent_correct$p[i],method="bonferroni",
  #                                         n=as.numeric(strsplit(percent_correct$expName[i], "-")[[1]][1]))
  # percent_correct$con_int[i] <- tmp['conf.int']
}
percent_correct$sig[percent_correct$p<0.05] <- '*'
percent_correct$sig[percent_correct$p<0.01] <- '**'
percent_correct$sig[percent_correct$p<0.001] <- '***'

# for appendix 1 
errorbar_2dot$expName <-'2-dot'
errorbar_4dot$expName <-'4-dot'
errorbar_6dot$expName <-'6-dot'
errorbar_10dot$expName <-'10-dot'
summary_each_exp <- rbind(errorbar_2dot,errorbar_4dot,errorbar_6dot,errorbar_10dot)
summary_each_exp$idnumber <- paste(summary_each_exp$participant,summary_each_exp$expName,summary_each_exp$correct_dot,summary_each_exp$FirstTouch,sep = '_')
percent_correct$idnumber <- paste(percent_correct$participant,percent_correct$expName,percent_correct$correct_dot,percent_correct$FirstTouch,sep = '_')
percent_correct$SE <- summary_each_exp$se[match(percent_correct$idnumber,summary_each_exp$idnumber)]
percent_correct1 <- apply(percent_correct,2,as.character)
# write.csv(percent_correct1,'C:/Users/aeo/Desktop/monkey cup/ms/percent_correct1.csv')



# the effect of target side, each experiment ----
sally_2dot <- df_sh%>%subset(participant=="Sally"&expName=='2-dot')
sally_4dot <- df_sh%>%subset(participant=="Sally"&expName=='4-dot')
sally_6dot <- df_sh%>%subset(participant=="Sally"&expName=='6-dot')
sally_10dot <- df_sh%>%subset(participant=="Sally"&expName=='10-dot')

hooke_2dot <- df_sh%>%subset(participant=="Hooke"&expName=='2-dot')
hooke_4dot <- df_sh%>%subset(participant=="Hooke"&expName=='4-dot')
hooke_6dot <- df_sh%>%subset(participant=="Hooke"&expName=='6-dot')
hooke_10dot <- df_sh%>%subset(participant=="Hooke"&expName=='10-dot')

des_leftright <- ddply(df_sh, c("participant","expName",'side_correct'),
                       summarise,  Mean = mean(correct*100), sd = sd(correct*100), n = sum(!is.na(correct)), se = sd / sqrt (n))

wilcox.test(correct ~ side_correct, data=hooke_2dot)
wilcoxonR(x=hooke_2dot$correct,g=hooke_2dot$side_correct)

wilcox.test(correct ~ side_correct, data=hooke_4dot)
wilcoxonR(x=hooke_4dot$correct,g=hooke_4dot$side_correct)

wilcox.test(correct ~ side_correct, data=hooke_6dot)
wilcoxonR(x=hooke_6dot$correct,g=hooke_6dot$side_correct)

wilcox.test(correct ~ side_correct, data=hooke_10dot)
wilcoxonR(x=hooke_10dot$correct,g=hooke_10dot$side_correct)


wilcox.test(correct ~ side_correct, data=sally_2dot)
wilcoxonR(x=sally_2dot$correct,g=sally_2dot$side_correct)

wilcox.test(correct ~ side_correct, data=sally_4dot)
wilcoxonR(x=sally_4dot$correct,g=sally_4dot$side_correct)

wilcox.test(correct ~ side_correct, data=sally_6dot)
wilcoxonR(x=sally_6dot$correct,g=sally_6dot$side_correct)

wilcox.test(correct ~ side_correct, data=sally_10dot)
wilcoxonR(x=sally_10dot$correct,g=sally_10dot$side_correct)

# # effect of dots 
# hooke <- df_sh %>% filter(participant=="Hooke")
# sally <- df_sh %>% filter(participant=="Sally")
# kruskal.test(correct~expName, 
#              data = hooke)
# epsilonSquared(x=hooke$correct,g=hooke$expName)
# pairwise.wilcox.test(hooke$correct,
#                      hooke$expName,
#                      p.adjust.method="fdr") #Pairwise Mann¨CWhitney
# 
# kruskal.test(correct~expName, 
#              data = sally)
# epsilonSquared(x=sally$correct,g=sally$expName)
# pairwise.wilcox.test(sally$correct,
#                      sally$expName,
#                      p.adjust.method="fdr") #Pairwise Mann¨CWhitney


# glmm accuray by side and experiment (number of dots) ##########################
df_sh$side_correct <- factor(df_sh$side_correct)
df_sh$expName <- factor(df_sh$expName)
sally2 <- df_sh%>%subset(participant=="Sally")
hooke2 <- df_sh%>%subset(participant=="Hooke")

# hooke
gmhooke <- glm(correct ~ side_correct*expName, 
                data=hooke2, 
                family = "binomial"(link="logit"))

summary(gmhooke)
Anova(gmhooke,type="III")

side_exp_hooke = emmeans(gmhooke, ~ side_correct *expName)
pairs(side_exp_hooke, simple = "side_correct",adjust="bonferroni",paired=TRUE)
pairs(side_exp_hooke, simple = "expName",adjust="bonferroni",paired=TRUE)

# Sally 
gmsally<- glm(correct ~ side_correct*expName,
               data=sally2,
               family = "binomial"(link="logit"))
summary(gmsally)
Anova(gmsally,type="III")
side_exp_sally = emmeans(gmsally, ~ side_correct *expName)
pairs(side_exp_sally, simple = "side_correct",adjust="bonferroni",paired=TRUE)
pairs(side_exp_sally, simple = "expName",adjust="bonferroni",paired=TRUE)

ddply(df_sh, c("participant","side_correct","expName"), summarise,  Mean = mean(correct), sd = sd(correct), n = sum(!is.na(correct)), se = sd / sqrt (n))
ddply(df_sh, c("participant","expName"), summarise,  Mean = mean(correct), sd = sd(correct), n = sum(!is.na(correct)), se = sd / sqrt (n))

